@@ -59,12 +59,12 @@ class SqlMergeOperator(SqlDecoratoratedOperator):
             database=self.target_table.database,
             conn_id=self.target_table.conn_id,
             schema=self.target_table.schema,
+            warehouse=self.target_table.warehouse,
             **kwargs,
         )
 
     def execute(self, context: Dict):
-        # self.conn_id = self.target_table.conn_id
-        conn_type = BaseHook.get_connection(self.conn_id).conn_type
+        conn_type = BaseHook.get_connection(self.conn_id).conn_type  # type: ignore
         if conn_type == "postgres":
             self.sql = postgres_merge_func(
                 target_table=self.target_table,
